==> haskell-basic-prelude-0.7.0-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-Ed5jtGNY21GIcvq9W7pcM5
key:                  basic-prelude-0.7.0-Ed5jtGNY21GIcvq9W7pcM5
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  cdd5a7da52aa2d584397628e20c64266
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-8.10.4/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/basic-prelude-0.7.0
hs-libraries:         HSbasic-prelude-0.7.0-Ed5jtGNY21GIcvq9W7pcM5
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    filepath-1.4.2.1 hashable-1.3.1.0-5wlJXyHm50SFuYmZaY4yzV
    text-1.2.4.1 transformers-0.5.6.2
    unordered-containers-0.2.13.0-8xrAhv2QGcsF4IHfxyp1m2
    vector-0.12.2.0-Fhpcj4oaE8d6h7vKPBvHg3

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basic-prelude-0.7.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-basic-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-3E5szsfxnbl9foTFyElrd5
key:                  basic-prelude-0.7.0-3E5szsfxnbl9foTFyElrd5
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  75f714846f43266e4c1e8c2422350ee2
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-8.10.4/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/basic-prelude-0.7.0
hs-libraries:         HSbasic-prelude-0.7.0-3E5szsfxnbl9foTFyElrd5
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    filepath-1.4.2.1 hashable-1.3.1.0-AFm7ygY4MxA76FjadItoSM
    text-1.2.4.1 transformers-0.5.6.2
    unordered-containers-0.2.13.0-Dm1EWWGKu5F1HgehuVxZbu
    vector-0.12.2.0-jK90aUeXx6Ehemvl3B500

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
